@@ -73,7 +73,7 @@ from functools import partial
 from celery.bin.base import Command, daemon_options
 from celery.platforms import detached, set_process_title, strargv
 
-__all__ = ['events']
+__all__ = ('events',)
 
 HELP = __doc__
 
