@@ -11,7 +11,7 @@ from celery import signals  # noqa
 
 from . import base  # noqa
 
-__all__ = ['TaskPool']
+__all__ = ('TaskPool',)
 
 W_RACE = """\
 Celery module with %s imported before eventlet patched\
