@@ -7,7 +7,7 @@ from math import ceil
 
 from kombu.utils.objects import cached_property
 
-__all__ = ['load_average', 'df']
+__all__ = ('load_average', 'df')
 
 
 if hasattr(os, 'getloadavg'):
