@@ -21,7 +21,7 @@ from celery.five import THREAD_TIMEOUT_MAX
 
 TIMER_DEBUG = os.environ.get('TIMER_DEBUG')
 
-__all__ = ['Entry', 'Schedule', 'Timer', 'to_timestamp']
+__all__ = ('Entry', 'Schedule', 'Timer', 'to_timestamp')
 
 
 class Timer(threading.Thread):
@@ -91,6 +91,7 @@ class Timer(threading.Thread):
                 pass
         except Exception as exc:
             logger.error('Thread Timer crashed: %r', exc, exc_info=True)
+            sys.stderr.flush()
             os._exit(1)
 
     def stop(self):
